pub struct AnyReceiptEnvelope<T = Log> {
pub inner: ReceiptWithBloom<Receipt<T>>,
pub type: u8,
}Expand description
Receipt envelope, as defined in EIP-2718.
Represents legacy and typed EIP-2718 receipts. Type ID 0 is encoded as untagged legacy; this
type does not preserve a literal 0x00 prefix.
Transaction receipt payloads are specified in their respective EIPs.
Fields
inner: ReceiptWithBloom<Receipt<T>>The receipt envelope.
type: u8The transaction type.
Implementations
Sourceimpl<T> AnyReceiptEnvelope<T>
impl<T> AnyReceiptEnvelope<T>
Sourceimpl<T> AnyReceiptEnvelope<T>where
T: Encodable,
impl<T> AnyReceiptEnvelope<T>where
T: Encodable,
Sourcepub fn rlp_payload_length(&self) -> usize
pub fn rlp_payload_length(&self) -> usize
Calculate the length of the rlp payload of the network encoded receipt.
Sourceimpl<T> AnyReceiptEnvelope<T>
impl<T> AnyReceiptEnvelope<T>
Sourcepub const fn is_success(&self) -> bool
pub const fn is_success(&self) -> bool
Sourcepub const fn cumulative_gas_used(&self) -> u64
pub const fn cumulative_gas_used(&self) -> u64
Returns the cumulative gas used at this receipt.