FullSignerSync

Trait FullSignerSync 

pub trait FullSignerSync<S>: SignerSync<S> + TxSignerSync<S> { }
A unifying trait for synchronous Ethereum signers that implement both SignerSync and TxSignerSync.

This trait enables dynamic dispatch (e.g., using Box<dyn FullSignerSync>) for types that combine both synchronous Ethereum signing and transaction signing functionalities.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, S> FullSignerSync<S> for T
where T: SignerSync<S> + TxSignerSync<S>,