pub struct AnyTransactionReceipt(pub WithOtherFields<TransactionReceipt<AnyReceiptEnvelope<Log>>>);Expand description
A catch-all receipt type for handling receipts on multiple networks.
Tuple Fields
0: WithOtherFields<TransactionReceipt<AnyReceiptEnvelope<Log>>>Implementations
Sourceimpl AnyTransactionReceipt
impl AnyTransactionReceipt
Sourcepub const fn new(
inner: WithOtherFields<TransactionReceipt<AnyReceiptEnvelope<Log>>>,
) -> AnyTransactionReceipt
pub const fn new( inner: WithOtherFields<TransactionReceipt<AnyReceiptEnvelope<Log>>>, ) -> AnyTransactionReceipt
Creates a new AnyTransactionReceipt.
Sourcepub fn into_parts(
self,
) -> (TransactionReceipt<AnyReceiptEnvelope<Log>>, OtherFields)
pub fn into_parts( self, ) -> (TransactionReceipt<AnyReceiptEnvelope<Log>>, OtherFields)
Splits the receipt into its inner receipt and unknown fields.
Sourcepub fn into_inner(self) -> TransactionReceipt<AnyReceiptEnvelope<Log>>
pub fn into_inner(self) -> TransactionReceipt<AnyReceiptEnvelope<Log>>
Consumes the type and returns the wrapped receipt.
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Returns true if the transaction was successful.
Sourcepub const fn deployed_contract(&self) -> Option<Address>
pub const fn deployed_contract(&self) -> Option<Address>
Returns the contract address if this was a deployment transaction.
Sourcepub const fn transaction_hash(&self) -> FixedBytes<32>
pub const fn transaction_hash(&self) -> FixedBytes<32>
Returns the transaction hash.
Sourcepub const fn tx_hash(&self) -> FixedBytes<32>
pub const fn tx_hash(&self) -> FixedBytes<32>
Alias for transaction_hash.
Sourcepub const fn block_hash(&self) -> Option<FixedBytes<32>>
pub const fn block_hash(&self) -> Option<FixedBytes<32>>
Returns the block hash if available.
Sourcepub const fn block_number(&self) -> Option<u64>
pub const fn block_number(&self) -> Option<u64>
Returns the block number if available.
Sourcepub fn cumulative_gas_used(&self) -> u64
pub fn cumulative_gas_used(&self) -> u64
Returns the cumulative gas used up to this transaction in the block.
Sourcepub const fn effective_gas_price(&self) -> u128
pub const fn effective_gas_price(&self) -> u128
Returns the effective gas price.
Sourcepub const fn other_fields(&self) -> &OtherFields
pub const fn other_fields(&self) -> &OtherFields
Returns a reference to the unknown fields.
Sourcepub const fn other_fields_mut(&mut self) -> &mut OtherFields
pub const fn other_fields_mut(&mut self) -> &mut OtherFields
Returns a mutable reference to the unknown fields.
Sourcepub fn deserialize_other<T>(&self) -> Result<T, Error>where
T: DeserializeOwned,
pub fn deserialize_other<T>(&self) -> Result<T, Error>where
T: DeserializeOwned,
Deserializes the unknown fields into a concrete type.
Sourcepub fn map_inner<U, F>(self, f: F) -> TransactionReceipt<U>
pub fn map_inner<U, F>(self, f: F) -> TransactionReceipt<U>
Maps the inner receipt envelope to a different type.
OtherFields are discarded while mapping.
Sourcepub fn try_map_inner<U, E, F>(self, f: F) -> Result<TransactionReceipt<U>, E>
pub fn try_map_inner<U, E, F>(self, f: F) -> Result<TransactionReceipt<U>, E>
Applies a fallible mapping function to the inner receipt envelope.
OtherFields are discarded while mapping.
Sourcepub fn convert<U>(self) -> TransactionReceipt<U>
pub fn convert<U>(self) -> TransactionReceipt<U>
Converts the receipt into a different envelope type.
OtherFields are discarded while mapping.
Sourcepub fn try_convert<U>(
self,
) -> Result<TransactionReceipt<U>, <U as TryFrom<AnyReceiptEnvelope<Log>>>::Error>
pub fn try_convert<U>( self, ) -> Result<TransactionReceipt<U>, <U as TryFrom<AnyReceiptEnvelope<Log>>>::Error>
Tries to convert the receipt into a different envelope type.
OtherFields are discarded while mapping.
Methods from Deref<Target = WithOtherFields<TransactionReceipt<AnyReceiptEnvelope<Log>>>>