FullSigner

Trait FullSigner 

pub trait FullSigner<S>: Signer<S> + TxSigner<S> { }
A unifying trait for asynchronous Ethereum signers that combine the functionalities of both Signer and TxSigner.

This trait enables dynamic dispatch (e.g., using Box<dyn FullSigner>) for types that combine both asynchronous Ethereum signing and transaction signing functionalities.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, S> FullSigner<S> for T
where T: Signer<S> + TxSigner<S>,